@@ -6,4 +6,4 @@ Created on Wed Dec  8 15:54:54 2021
 """
 
 from ._version import __version__
-from ._dock_widget import napari_experimental_provide_dock_widget, napari_provide_sample_data, napari_get_reader
+from ._dock_widget import  napari_get_reader
